@@ -4,7 +4,7 @@
 modname = 'jqplot'
 distname = 'cubicweb-jqplot'
 
-numversion = (0, 1, 0)
+numversion = (0, 1, 1)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -34,7 +34,8 @@ data_files = [
     [THIS_CUBE_DIR, [fname for fname in glob('*.py') if fname != 'setup.py']],
     ]
 # check for possible extended cube layout
-for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'wdoc', 'i18n', 'migration'):
+for dname in ('entities', 'views', 'sobjects', 'hooks', 'schema', 'data', 'wdoc',
+              'i18n', 'migration', join('data', 'plugins')):
     if isdir(dname):
         data_files.append([join(THIS_CUBE_DIR, dname), listdir(dname)])
 # Note: here, you'll need to add subdirectories if you want
